Docking Evaluation
==================

Classes and pipelines for docking-based evaluation of generated molecules.

Docking Classes
---------------

.. automodule:: shepherd_score.evaluations.docking.docking
   :members:
   :undoc-members:
   :show-inheritance:

Docking Pipelines
-----------------

.. automodule:: shepherd_score.evaluations.docking.pipelines
   :members:
   :undoc-members:
   :show-inheritance:

Docking Targets
---------------

.. automodule:: shepherd_score.evaluations.docking.targets
   :members:
   :undoc-members:
   :show-inheritance:

Protein-Ligand Interactions
---------------------------

.. automodule:: shepherd_score.evaluations.docking.interactions
   :members:
   :undoc-members:
   :show-inheritance:
